#!/bin/bash

logfile=/var/log/pre_firstboot.log
use_backsys=$1
grub_bootdev=$2

logger()
{
	echo "" >> $logfile
	echo "$@" >> $logfile
	echo "" >> $logfile
}


do_install_backsys()
{
	logger "Begin to Install baksys ...."	
	
	[ -d /opt/backup-recover ] || (logger "Dir /opt/backup-recover is not exist.";exit 1)
	reuse=0
	if [ -d /opt/backup-recover/root ];then
		logger "baksys exist."
		reuse=1
	fi

	if [ "$reuse" = "0" ];then
		tar -xf /opt/baksys/baksys-full.tar.gz -C /opt/backup-recover
	else
		tar -C /opt/backup-recover/usr/bin -xf /opt/baksys/baksys-full.tar.gz usr/bin/backuprecover
	fi

	cp -f /etc/fstab /opt/backup-recover/root/host_os_fstab
	cp -f /etc/lsb-release /opt/backup-recover/root/host_os_lsb_release

	sed -i 's/PRETTY_NAME=.*/PRETTY_NAME="方德一键还原"/' /opt/backup-recover/usr/lib/os-release

	logger "移除繁体字"
	rm -rf /opt/backup-recover/usr/share/fonts/truetype/founder-set/fz*fw.ttf
	rm -rf /opt/baksys
	sync	

	update-grub
	grub-install $grub_bootdev
	logger "End of baksys install"

}

preload_nvidia_config()
{
	logger "Starting preload nvidia configuration."
	if [ -f /usr/bin/nvidia-nfs-autoconf.sh ];then
		/usr/bin/nvidia-nfs-autoconf.sh
        if [ -x /usr/sbin/update-initramfs ]; then
                update-initramfs -u
        fi
	else
		logger "Cannot find nvidia auto conf file."
	fi
	logger "End of preload nvidia configuration."
}


do_set_resolution()
{
	logger "Begin to set_resolution ...."	
	
	sed -i '/#GRUB_GFXMODE=640x480/aGRUB_GFXPAYLOAD_LINUX=keep' /etc/default/grub
	sed -i '/#GRUB_GFXMODE=640x480/aGRUB_GFXMODE=1920x1080,1280x1024,auto' /etc/default/grub

	update-grub
	logger "End of set_resolution."
}


install_keyfiles_pkg() {
	echo "install kefiles pkg"
	apt-get -y --install-suggests install keyfiles-check-assistant
	apt-get -y --install-suggests install keyfiles-check
}


if [ "$use_backsys" = "true" ];then
    do_install_backsys
fi

install_keyfiles_pkg
preload_nvidia_config
do_set_resolution

# repair PRE4-524
sed -i 's/recordfail$/#recordfail/' /boot/grub/grub.cfg
sed -i 's/ubuntu/nfs/' /etc/hostname
sed -i 's/ubuntu/nfs/' /etc/hosts

logger "=========================END of pre_firstboot=================="
